*****************************************
* T1_BalanceGender.do
	*Table 1:		Balancing tests
	*Last Updated 16 May 2015	
	
	*Runs balance tests separately by gender

		
***************************************** 


#delimit ;
tempfile temp tempdata ;
use "$work/$specdata",clear;


*Data statements: see specification_setup.do;
$keepstatement;


save `temp';


* Keep only necessary variables -- $covbal is covariates minus r_sex;
keep  r_sex $covbal _totexp wage jollibee occupation wageX occX 
;

save `tempdata', replace;

*****************************
*	Compute summary means for tables
*****************************;

*Define subgroups;
local O1 "keep if jollibee == 0";					// No voucher
local O2 "keep if jollibee == 1";					// Voucher
local O3 "keep if wage == 0 & occupation == 0"; 	// No information
local O4 "keep if wage == 1";						// Wage information
local O5 "keep if occupation == 1";					// Qualification information


local P1 "novoucher";
local P2 "voucher";
local P3 "noinfo";
local P4 "wage";
local P5 "qualification";

* Loop over 6 subgroups;

forval i = 1/5{;
	
	*Loop over each covariate;
	foreach var in r_sex $covbal {;
		use `tempdata', clear;
	*Restrict data	based on subgroups (above);
			`O`i'';
	*Collapse means;
		collapse (mean) mean`P`i'' = `var' ;
	*Generate names	;
		gen str15 var = "`var'";
		
		tempfile temp`var';
		save `temp`var'' ;
	};


	
*Append variable means into one subgroup file;
use `tempr_sex', clear;

foreach var in $covbal {;
	append using `temp`var'';
	*order var;
	*list;	
	};
	egen id = seq();
	tempfile means_`P`i'';
	save  `means_`P`i''';
};

* Merge across all subgroups;
use `means_novoucher',clear;

forval i = 2/5{;
	di "merging with `P`i''";
	merge 1:1 id using `means_`P`i''';
		assert _merge == 3;
		drop _merge;
};

drop id; 
*Output Balance Means;
outsheet using "$output/T1_balance $ST.xls",replace;


*****************************
*	Compute p-values for balance tests
*****************************;



tempfile fpvalues_jollibee fpvalues_wage fpvalues_occupation;

// Compute p-values for various tests. 
local OO1 "jollibee";
local OO2 "wage";
local OO3 "occupation";

local res1 "";							// Sample restrictions for comparision;
local res2 "if occupation == 0";
local res3 "if wage == 0";

** Loop over all three tests;
forval j = 1/3{;

	use `temp',clear   ;

	* Loop over covariates;
		foreach var in r_sex $covbal{;


			reg `var' `OO`j'' `res`j'',cluster(bgy);
				testparm `OO`j'';
					*gen Fstat_`var' = `r(F)';
					gen pval_`var' = `r(p)';
		};


collapse (mean)  pval*;

xpose,varname clear ;
rename v1 `OO`j'';
save `fpvalues_`OO`j''',replace;


};

* Append p-values;
use `fpvalues_jollibee',clear;
egen id = seq();

append using `fpvalues_wage';

append using `fpvalues_occupation';

collapse (max) jollibee  wage occupation id,by(_varname);
sort id;
outsheet  using "$output/fvalues_$ST $RES $MM.xls",replace;



*****************************
*	Check overall balance
*****************************;

#delimit ;
use `temp',clear; 

*Voucher vs No Voucher;
xi: reg jollibee r_sex $covbal  ,cluster(bgy);    
testparm r_sex $covbal;

*Wage vs. No Information;
xi: reg wage r_sex $covbal  if occupation == 0,cluster(bgy);    
testparm r_sex $covbal;

*Qualification vs. No information;
xi: reg occupation r_sex $covbal if wage  == 0,cluster(bgy) ;    
testparm r_sex $covbal;

* Gen sample sizes;
tab jollibee ;
tab wage ;
tab occupation;

exit;
